@@ -12,6 +12,7 @@
 #define ALEX_IF_GHC_GT_500 #if __GLASGOW_HASKELL__ > 500
 #define ALEX_IF_GHC_LT_503 #if __GLASGOW_HASKELL__ < 503
 #define ALEX_IF_GHC_GT_706 #if __GLASGOW_HASKELL__ > 706
+#define ALEX_IF_GHC_GE_901 #if __GLASGOW_HASKELL__ >= 901
 #define ALEX_ELIF_GHC_500 #elif __GLASGOW_HASKELL__ == 500
 #define ALEX_IF_BIGENDIAN #ifdef WORDS_BIGENDIAN
 #define ALEX_ELSE #else
@@ -57,6 +58,7 @@ uncheckedShiftL# = shiftL#
 ALEX_ENDIF
 
 {-# INLINE alexIndexInt16OffAddr #-}
+alexIndexInt16OffAddr :: AlexAddr -> Int# -> Int#
 alexIndexInt16OffAddr (AlexA# arr) off =
 ALEX_IF_BIGENDIAN
   narrow16Int# i
@@ -66,7 +68,10 @@ ALEX_IF_BIGENDIAN
         low  = int2Word# (ord# (indexCharOffAddr# arr off'))
         off' = off *# 2#
 ALEX_ELSE
-  indexInt16OffAddr# arr off
+ALEX_IF_GHC_GE_901
+  int16ToInt#
+ALEX_ENDIF
+    (indexInt16OffAddr# arr off)
 ALEX_ENDIF
 #else
 alexIndexInt16OffAddr arr off = arr ! off
@@ -74,6 +79,7 @@ alexIndexInt16OffAddr arr off = arr ! off
 
 #ifdef ALEX_GHC
 {-# INLINE alexIndexInt32OffAddr #-}
+alexIndexInt32OffAddr :: AlexAddr -> Int# -> Int#
 alexIndexInt32OffAddr (AlexA# arr) off =
 ALEX_IF_BIGENDIAN
   narrow32Int# i
@@ -87,7 +93,10 @@ ALEX_IF_BIGENDIAN
    b0   = int2Word# (ord# (indexCharOffAddr# arr off'))
    off' = off *# 4#
 ALEX_ELSE
-  indexInt32OffAddr# arr off
+ALEX_IF_GHC_GE_901
+  int32ToInt#
+ALEX_ENDIF
+    (indexInt32OffAddr# arr off)
 ALEX_ENDIF
 #else
 alexIndexInt32OffAddr arr off = arr ! off
